.. codestare-msg-compiler documentation master file, created by
   sphinx-quickstart on Tue Feb  1 10:29:12 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Codestare Proto Message Setuptools Plugin
=========================================

This site covers the usage the ``codestare-msg-compiler`` cli tools and
setuptools commands used to generate flexible protobuf python bindings.

Getting started
---------------

Installation and basic usage of the setuptools plugin is covered in the tutorial.

.. toctree::
    :maxdepth: 2

    getting-started



.. _cli-docs:

CLI
---

Dig deeper into specific topics:

.. toctree::
    :maxdepth: 2
    :glob:

    cli/*


.. _api-docs:

API
---

Autogenerated API docs

.. toctree::
    :maxdepth: 1
    :glob:

    api/*

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
